%define gitname theme
%define theme   Default
%define scriptdir %{_datadir}/bootsplash/scripts
%define mga_bg  %{_datadir}/mga/backgrounds

Name:           mageia-theme
Version:        8.0
Release:        %mkrel 2
Summary:        %{_vendor} theme for plymouth and desktop background
Group:          Graphics/Utilities
License:        GPL and CC BY-SA 3.0
URL:            http://gitweb.mageia.org/software/design/theme
# Mageia is the upstream for this package ( http://gitweb.mageia.org/software/design/theme/ )
# To generate the package you need to `make export` in the git repo or download the git snapshot
# from gitweb (or alternatively rely on `mgarepo sync -d`)
Source0:        http://gitweb.mageia.org/software/design/theme/snapshot/%{gitname}-%{version}.tar.xz
Source100:      glib2-branding.gschema.override.in
BuildArch:      noarch

Requires(preun): bootsplash
Requires(preun): rpm-helper >= %{rpmhelper_required_version}
Requires(posttrans): rpm-helper >= %{rpmhelper_required_version}
# Required for mga-bg-res
Requires:       monitor-edid
Requires:       plymouth-plugin-script
Requires:       plymouth-system-theme
Recommends:     mageia-theme-screensavers
Provides:       plymouth(system-theme)

# (akien) Obsolete those for Mageia 6 when making mageia-theme monolithic
# The split was not really useful, and making the spec very hard to read
Obsoletes:      mageia-theme-common < 6.5-1
Obsoletes:      mageia-theme-Default < 6.5-1
Provides:       mageia-theme-Default = %{version}-%{release}
# Transitional package to fix obsoletes mageia-theme-Default had
Requires:       mageia-theme-Default
Obsoletes:      mageia-theme-kde-background < 6.5-1
Provides:       mageia-theme-kde-background = %{version}-%{release}
Obsoletes:      mageia-theme-gnome < 6.5-1
Provides:       mageia-theme-gnome = %{version}-%{release}
Conflicts:      plymouth < 0.9.2-7.mga6

%description
This package contains the %{_vendor} plymouth theme and desktop background
image with sizes and configuration for different resolutions.

The signature background was chosen among high quality submissions from the
%{_vendor} community for the %{_vendor} %{distro_release} artwork contest.

%package screensavers
Summary:        %{_vendor} screensavers collection
License:        CC BY-SA 3.0
Obsoletes:      mageia-theme-screensaver < 6.5-1
Obsoletes:      mageia-theme-Default-screensaver < 6.5-1
Provides:       mageia-theme-screensaver = %{version}-%{release}
Provides:       mageia-theme-Default-screensaver = %{version}-%{release}

%description screensavers
This package contains the screensavers associated with the %{_vendor} theme.

They are a collection of high-quality photographs under libre licenses
taken by members of the %{_vendor} community.

%package extra
Summary:        Additional backgrounds from %{_vendor} users

%description extra
This package contains extra backgrounds to supplement the default selection.
Those images were other submissions to the %{_vendor} %{distro_release} artwork contest.

%package Default
Summary:        Transitional (empty) package
Conflicts:      mageia-theme-Default < 6.5-1

%description Default
Transitional (empty) package.

%prep
%setup -q -n %{gitname}-%{version}
cp -a %{SOURCE100} glib2-branding.gschema.override.in


%build
sed "s,@@WALLPAPER_URI@@,file:///usr/share/mga/backgrounds/default.png," \
  glib2-branding.gschema.override.in > glib2-branding.gschema.override


%install
%make_install

# Kept for compatibility after default.jpg -> default.png rename
ln -sf default.png %{buildroot}%{_datadir}/mga/backgrounds/default.jpg

# KDE metadata
install -d %{buildroot}%{_datadir}/wallpapers/%{_vendor}/contents/images
pushd %{buildroot}%{_datadir}/wallpapers/%{_vendor}/contents/images
for i in "1024x600" "1280x768" "1280x1024" "1600x1200" "3840x2160" "1920x1200" "3440x1440"; do
  ln -s %{mga_bg}/%{_vendor}-%{theme}-$i.png $i.png
done
popd

cat > %{buildroot}%{_datadir}/wallpapers/%{_vendor}/metadata.desktop << EOF
[Desktop Entry]
Name=%{_vendor}
X-KDE-PluginInfo-Name=%{_vendor}
X-KDE-PluginInfo-Author=Mageia Artwork Team
X-KDE-PluginInfo-Email=atelier@ml.mageia.org
X-KDE-PluginInfo-License=GPL
EOF

# GNOME metadata
install -d %{buildroot}%{_datadir}/gnome-background-properties
for i in "1024x600" "1280x768" "1280x1024" "1600x1200" "3840x2160" "1920x1200" "3440x1440"; do
cat > %{buildroot}%{_datadir}/gnome-background-properties/%{_vendor}-%{theme}-$i.xml << EOF
<?xml version="1.0" encoding="UTF-8"?>
<!DOCTYPE wallpapers SYSTEM "gnome-wp-list.dtd">
<wallpapers>
	<wallpaper deleted="false">
		<name>%{theme} Mageia Background</name>
		<filename>%{_datadir}/wallpapers/%{_vendor}/contents/images/$i.png</filename>
		<options>zoom</options>
		<shade_type>solid</shade_type>
		<pcolor>#66ba00</pcolor>
	</wallpaper>
</wallpapers>
EOF
done

install -d %{buildroot}%{_datadir}/glib-2.0/schemas
install -m644 glib2-branding.gschema.override %{buildroot}%{_datadir}/glib-2.0/schemas/


# Use posttrans as post is run before old package is removed, and we may select a resolution
# which then gets removed.
%posttrans
if [ -z "$DURING_INSTALL" ]; then
  if [ -x %{scriptdir}/switch-themes ]; then
    %{scriptdir}/switch-themes %{_vendor}-%{theme}
  fi
else
  if [ -f %{_sysconfdir}/sysconfig/bootsplash ]; then
    perl -pi -e 's/^\s*SPLASH=.*/SPLASH=auto/; s/^\s*THEME=.*/THEME=%{_vendor}-%{theme}/' %{_sysconfdir}/sysconfig/bootsplash
  fi
  %{_sbindir}/plymouth-set-default-theme %{_vendor}-%{theme}
fi
%_post_service mga-bg-res
# plymouth-set-default-theme defaults to 4:3 on update so fix it.
%{_libexecdir}/mga-bg-res > /dev/null 2>&1

%preun
if [ "$1" == "0" ]; then
  if [ -x %{scriptdir}/remove-theme ]; then
    %{scriptdir}/remove-theme %{_vendor}-%{theme}
  fi
  for symlink in default.jpg default.png; do
    link=`readlink %{mga_bg}/$symlink`
    slink=${link%%-*}
    if [ "$slink" == "%{_vendor}-%{theme}" ]; then rm -f %{mga_bg}/$symlink; fi
  done
fi
%_preun_service mga-bg-res

%files
%{mga_bg}/%{_vendor}-%{theme}*.png
%{mga_bg}/default.jpg
%ghost %{mga_bg}/default.png
%{_datadir}/gfxboot/themes/%{_vendor}-%{theme}/
%{_datadir}/glib-2.0/schemas/glib2-branding.gschema.override
%{_datadir}/gnome-background-properties/%{_vendor}-%{theme}-*.xml
%{_datadir}/plymouth/themes/%{_vendor}-%{theme}/
%{_datadir}/wallpapers/%{_vendor}/
%{_libexecdir}/mga-bg-res
%{_unitdir}/mga-bg-res.service

%files screensavers
%dir %{_datadir}/mga/screensaver
%{_datadir}/mga/screensaver/*-*.jpg

%files extra
%{mga_bg}/%{_vendor}-%{theme}-{4,5,6,7}.jpg
%{mga_bg}/Extra-Background*.jpg

%files Default


%changelog
* Wed Feb 03 2021 tmb <tmb> 8.0-2.mga8
+ Revision: 1674759
- g-s-d:. remove deprecated help key override (mga#28290)

* Sun Jan 10 2021 schultz <schultz> 8.0-1.mga8
+ Revision: 1670759
- Artworkfor Mageia 8
- Default mga-bg-res to 16:9

* Sat Feb 15 2020 umeabot <umeabot> 7.0-4.mga8
+ Revision: 1528502
- Mageia 8 Mass Rebuild

* Thu Aug 22 2019 ovitters <ovitters> 7.0-3.mga8
+ Revision: 1431089
- sync with gnome-settings-daemon media-plugin gschema change

* Sun Jun 09 2019 wally <wally> 7.0-2.mga7
+ Revision: 1399709
- own default.png

* Sun May 05 2019 schultz <schultz> 7.0-1.mga7
+ Revision: 1396369
- 7.0
  - Mga 7 artwork
  - Added support for 3440x1440 ultrawide

* Wed Oct 31 2018 martinw <martinw> 6.5-1.mga7
+ Revision: 1326796
- better fix for avoiding monitor-edid hang
  o we still want to create the link to the default background image

* Mon Oct 29 2018 martinw <martinw> 6.4-3.mga7
+ Revision: 1326562
- don't run mga-bg-res post-install when using drakx-in-chroot/draklive2
  o monitor-edid sometimes hangs when run in a nested X session

* Tue Sep 18 2018 umeabot <umeabot> 6.4-2.mga7
+ Revision: 1262994
- Mageia 7 Mass Rebuild

* Sat May 20 2017 akien <akien> 6.4-1.mga6
+ Revision: 1103604
- 6.4: Rework plymouth boot animation (mga#19860)

* Sun May 07 2017 akien <akien> 6.3-1.mga6
+ Revision: 1099469
- 6.3: Plymouth: Improve scaling and aspect ratio handling

* Thu May 04 2017 akien <akien> 6.2-1.mga6
+ Revision: 1099040
- 6.2, update gfxboot images

* Sun Oct 09 2016 schultz <schultz> 6.1-1.mga6
+ Revision: 1059838
- 6.1
- Fix gfxboot images (mga#19187)
- Add further gfxboot instructions to Readme.md

* Sun Sep 25 2016 barjac <barjac> 6.0-4.mga6
+ Revision: 1056110
- run mga-bg-res rather than force 4:3 on update

* Mon Sep 19 2016 barjac <barjac> 6.0-3.mga6
+ Revision: 1054294
- Only replace default.png if it does not exist as file or symlink

* Mon Sep 19 2016 tv <tv> 6.0-2.mga6
+ Revision: 1054100
- fix bogus macro used in provide/obsoletes (thus fixing upgrade)
+ akien <akien>
- Fix distro release in descriptions

* Sun Sep 18 2016 akien <akien> 6.0-1.mga6
+ Revision: 1053681
- Add a transitional mageia-theme-Default package to fix overpowered Obsoletes
  o If I find the guy who used non strictly-versioned Obsoletes...
- Merge -gnome and -kde-background packages back in main package
  o They only contained some metadata and symlinks
  o The -gnome metadata depended on symlinks in the -kde-background package,
    so it was actually broken
- Remove the extraneous -Default part of package names
  o mageia-theme-Default becomes mageia-theme
  o mageia-theme-Default-screensaver becomes mageia-theme-screensavers
- Change versioning to match distro version (now 6.0)
- Removed extraneous backgrounds and screensavers from Mageia 5
- Converted Mageia 6 screensavers to JPG (photos)
- Dropped the non-working GIMP scripts
- Simplify %%install step
- Remove obsolete stuff from %%preun and %%posttrans
- Get rid of empty -common package
- Remove obsolete Obsoletes :)
- Refactoring: remove macros for multiple themes packaging
  o We package only one theme, and they make everything harder to read
  o Part of the work for mga#19395
- Another default.jpg -> default.png fix
- Simplify default.jpg symlink

* Sat Sep 17 2016 barjac <barjac> 1.5.0.52-3.mga6
+ Revision: 1053542
- move default.jpg creation from mga-bg-res to package spec

* Wed Sep 14 2016 barjac <barjac> 1.5.0.52-2.mga6
+ Revision: 1052919
- fix conflict

* Wed Sep 14 2016 barjac <barjac> 1.5.0.52-1.mga6
+ Revision: 1052896
- switch to .png for plymouth background and provide correct aspect ratio

* Mon Aug 15 2016 akien <akien> 1.5.0.51-1.mga6
+ Revision: 1046481
- Version 1.5.0.51: Fixed mga-bg-res for new 16:9 resolution
- Use gitweb snapshot URL for mgarepo sync -d

* Thu Aug 11 2016 schultz <schultz> 1.5.0.50-1.mga6
+ Revision: 1045748
- 1.5.0.50
- remove old plymouth image and clean script

* Thu Aug 11 2016 schultz <schultz> 1.5.0.49-1.mga6
+ Revision: 1045704
- 1.5.0.49
- add Mageia logo to backgrounds, plymouth & gfxboot
- new plymouth theme for Mageia 6
- 1.5.0.49
- add Mageia logo to backgrounds, gfxboot & plymouth
- new plymouth theme for mga6
- 1.5.0.48
  remove mga5 background that was missed
- 1.5.0.47
  bump to fix sync issue
- 1.5.0.46
  Initial mga6 artwork
- 1.5.0.45
- Initial artwork for Mga6
+ umeabot <umeabot>
- Mageia 6 Mass Rebuild

* Wed Dec 02 2015 ovitters <ovitters> 1.5.0.44-3.mga6
+ Revision: 907798
- bump rel
- remove post/postun for glib-compile-schemas (trigger should take care of it)

* Mon Nov 02 2015 ovitters <ovitters> 1.5.0.44-2.mga6
+ Revision: 897387
- remove external-editor gschema override as eog does not support this anymore

* Sat May 09 2015 akien <akien> 1.5.0.44-1.mga5
+ Revision: 821605
- 1.5.0.44:
  o mga-bg-res: Use monitor-edid directly instead of monitor-probe (mga#15896)
  o mga-bg-res: Make sure to default to 4:3 aspect ratio if monitor-edid fails (previous fix was incomplete)

* Sat May 02 2015 akien <akien> 1.5.0.43-1.mga5
+ Revision: 821008
- Version 1.5.0.43
  o mga-bg-res: now packaged in mageia-theme-Default
  o mga-bg-res: now a systemd service using monitor-probe
  o Makefile cleanups
+ wally <wally>
- drop Mdv parts from posttrans scripts

* Thu Mar 05 2015 akien <akien> 1.5.0.42-1.mga5
+ Revision: 817787
- 1.5.0.42
- New default background set based on current market monitor resolutions

* Tue Feb 10 2015 alien <alien> 1.5.0.41-2.mga5
+ Revision: 814591
- Require mga-bg-res to handle changed resolution at login time

* Sat Jan 17 2015 schultz <schultz> 1.5.0.41-1.mga5
+ Revision: 811086
- 1.5.0.41
- fix file list
- fix xml referencies in spec for extra
- 1.5.0.40
- add screensavers for mga5
- add additional backgrounds for mga5

* Sat Jan 10 2015 akien <akien> 1.5.0.39-1.mga5
+ Revision: 809664
- 1.5.0.39: Centered logo on plymouth theme (mg#14864)
- Fix Atelier contact email

* Tue Dec 16 2014 akien <akien> 1.5.0.38-1.mga5
+ Revision: 803492
- 1.5.0.38: initial Mageia 5 artwork integration

* Wed Oct 15 2014 umeabot <umeabot> 1.5.0.37-6.mga5
+ Revision: 740838
- Second Mageia 5 Mass Rebuild

* Thu Oct 09 2014 colin <colin> 1.5.0.37-5.mga5
+ Revision: 737782
- Apply the Mageia branding to gdm/screen-sheild login screens mga#14131

* Tue Sep 16 2014 umeabot <umeabot> 1.5.0.37-4.mga5
+ Revision: 682128
- Mageia 5 Mass Rebuild
+ tv <tv>
- s/uggests:/Recommends:/

* Thu Feb 13 2014 ovitters <ovitters> 1.5.0.37-3.mga5
+ Revision: 590389
- back to default theme as diskdrake works under Adwaita
- remember numlock state (bug was fixed several GNOME releases ago)

* Sun Jan 26 2014 colin <colin> 1.5.0.37-2.mga4
+ Revision: 568253
- Set the screensaver background in gnome-shell (mga#9304)
- Add drakconf to the default applications (otherwise unchanged from GNOME defaults - mga#12288)

* Tue Jan 14 2014 schultz <schultz> 1.5.0.37-1.mga4
+ Revision: 566549
- 1.5.0.37
- fix logo on backgrounds
- add final screensavers

* Thu Jan 09 2014 schultz <schultz> 1.5.0.36-2.mga4
+ Revision: 565810
- fix directory creation for gnome xml files
  fix file list
- add mga background in gnome default folder
- fix export inctructions, were using git now
- update extra package description
- 1.5.0.36
- Add artwork for MGA4
- Add support for 2560x1920

* Sun Jan 05 2014 ennael <ennael> 1.5.0.36-1.mga4
+ Revision: 564883
- fix files list
- Mageia 4 theme

* Sat Oct 19 2013 umeabot <umeabot> 1.5.0.35-4.mga4
+ Revision: 531717
- Mageia 4 Mass Rebuild

* Thu Aug 08 2013 tmb <tmb> 1.5.0.35-3.mga4
+ Revision: 464708
- dont try to override org.gnome.settings-daemon.plugins.updates,
  as we dont install the schema at all

* Fri May 24 2013 ovitters <ovitters> 1.5.0.35-2.mga4
+ Revision: 426451
- default to Oxygen-gtk

* Wed Apr 17 2013 ennael <ennael> 1.5.0.35-1.mga3
+ Revision: 410259
- update artwork to fit better usability

* Tue Apr 02 2013 ennael <ennael> 1.5.0.34-1.mga3
+ Revision: 407158
- Move Mageia logo on the left side

* Wed Mar 27 2013 schultz <schultz> 1.5.0.33-1.mga3
+ Revision: 405848
- 1.5.0.33
- fix file naming properly this time.
- 1.5.0.31
- actually add extra background, fix file list
- 1.5.0.30
- Plymouth
  - Remove unused images
  - Mageia 3 design
- Extra Backgrounds
  -Mageia 3 images

* Sun Mar 24 2013 ennael <ennael> 1.5.0.29-1.mga3
+ Revision: 404848
- New design for Mageia 3

* Sat Jan 12 2013 umeabot <umeabot> 1.5.0.28-8.mga3
+ Revision: 359298
- Mass Rebuild - https://wiki.mageia.org/en/Feature:Mageia3MassRebuild
+ boklm <boklm>
- Update group: Graphics/Other -> Graphics/Utilities

* Tue Nov 27 2012 ovitters <ovitters> 1.5.0.28-7.mga3
+ Revision: 322320
- update groups
- workaround gnome-settings-daemon 100%% CPU usage + blinking numlock bug

* Wed Aug 29 2012 colin <colin> 1.5.0.28-5.mga3
+ Revision: 285577
- Bump release to be newer than mga2 version

* Wed Aug 29 2012 colin <colin> 1.5.0.28-3.mga3
+ Revision: 285574
- Do not regenerate initrd when first installed (mga#6692, mga#5730, mga#5782)

* Sun Jun 03 2012 ennael <ennael> 1.5.0.28-2.mga3
+ Revision: 253590
- fix plymouth update (tmb)

* Sun Jun 03 2012 ennael <ennael> 1.5.0.28-1.mga3
+ Revision: 253578
- Use design from original author

* Sat May 12 2012 ennael <ennael> 1.5.0.27-1.mga2
+ Revision: 235521
- use proper logo for gfxboot

* Sat May 12 2012 ennael <ennael> 1.5.0.26-1.mga2
+ Revision: 235470
- Fix screensaver images

* Fri May 11 2012 ennael <ennael> 1.5.0.25-1.mga2
+ Revision: 235301
- fix files list for extras
- new screensavers and extra backgrounds

* Thu May 10 2012 ennael <ennael> 1.5.0.24-2.mga2
+ Revision: 235031
- Fix color for texts (#5676)
+ colin <colin>
- Require newer bootsplash (mga#5593)

* Thu Apr 19 2012 schultz <schultz> 1.5.0.23-1.mga2
+ Revision: 231755
- 1.5.0.23
- fix plymouth scaling issues (TeaAge)
- 1.5.0.23
- fix plymouth scaling

* Fri Apr 13 2012 ennael <ennael> 1.5.0.22-1.mga2
+ Revision: 230692
- new theme for Plymouth

* Thu Apr 12 2012 ennael <ennael> 1.5.0.21-3.mga2
+ Revision: 230383
- new gfxboot theme for Mageia 2

* Wed Apr 11 2012 dmorgan <dmorgan> 1.5.0.20-3.mga2
+ Revision: 230245
- Run %%post for wallpaper install

* Wed Apr 11 2012 dmorgan <dmorgan> 1.5.0.20-2.mga2
+ Revision: 230239
- Point to default.jpg image

* Tue Apr 10 2012 ennael <ennael> 1.5.0.20-1.mga2
+ Revision: 230091
- new backgrounds for Mageia 2

* Tue Apr 03 2012 ovitters <ovitters> 1.5.0.18-3.mga2
+ Revision: 228137
- add gschema override to provide GNOME background

* Mon Oct 10 2011 mikala <mikala> 1.5.0.18-2.mga2
+ Revision: 153655
- Bump mkrel to be higher than 1/updates
+ schultz <schultz>
- clean spec

* Fri Oct 07 2011 schultz <schultz> 1.5.0.18-1.mga2
+ Revision: 152591
- Update to 1.5.0.18
  add new mga.script (Thanks Teage) fixes mga# 1332, plymouth dots misalined

* Mon Jul 18 2011 mikala <mikala> 1.5.0.17-3.mga2
+ Revision: 125698
- Add a mageia-theme-kde-background subpackage (fix mga #1309)

* Mon May 30 2011 pterjan <pterjan> 1.5.0.17-2.mga1
+ Revision: 100765
- Rebuild with fixed mkrel

* Mon May 30 2011 ennael <ennael> 1.5.0.17-1.mga1.
+ Revision: 100743
- remove uneeded gfxboot files list
- remove unnecessary files in theme

* Thu May 26 2011 ennael <ennael> 1.5.0.16-1.mga1
+ Revision: 100453
- fix plymouth glitch (#1413)
- fix Mageia logo in backgrounds

* Mon May 23 2011 schultz <schultz> 1.5.0.15-1.mga1
+ Revision: 100277
- Update to 1.5.0.15
- add logo on backgrounds

* Sun May 22 2011 ahmad <ahmad> 1.5.0.14-2.mga1
+ Revision: 100159
- Obsolete old mandriva-theme-{Flash,Free,One,Powerpack}-screensaver properly

* Fri May 20 2011 schultz <schultz> 1.5.0.14-1.mga1
+ Revision: 99861
- Readd 1024x768 background
  Update to 1.5.0.14

* Mon May 16 2011 pterjan <pterjan> 1.5.0.13-3.mga1
+ Revision: 99194
- Drop useless trigger
+ ahmad <ahmad>
- Change %%post to %%posttrans, to be sure the symlink to default.jpg will be
  updated (mga#1295)
- Delete the .jpg symlinks in %%posttrans, the ones that were used for the timed
  wallpapers (both the Mandriva and Mageia ones); the same for the .xml symlink

* Sun May 15 2011 ennael <ennael> 1.5.0.13-1.mga1
+ Revision: 98893
- remove hour based backgrounds
+ schultz <schultz>
- Update backgrounds to final (Hopefully actual final this time)

* Mon May 02 2011 schultz <schultz> 1.5.0.9-1.mga1
+ Revision: 94313
- Release 1.5.0.9
- Update backgrounds for provisional final
- New lock.png for plymouth
- new tarball for time of the day backgrounds and updated Mageia-Default.xml

* Tue Apr 19 2011 dams <dams> 1.5.0.7-1.mga1
+ Revision: 88475
- Fix Mageia.xml to fix background slideshow

* Mon Apr 04 2011 ennael <ennael> 1.5.0.6-1.mga1
+ Revision: 80465
- fix Plymouth images

* Thu Mar 31 2011 ennael <ennael> 1.5.0.5-2.mga1
+ Revision: 79262
- add obsoletes on mandriva-theme-extra

* Thu Mar 31 2011 dmorgan <dmorgan> 1.5.0.5-1.mga1
+ Revision: 79199
- Update artworks

* Thu Mar 31 2011 dmorgan <dmorgan> 1.5.0.4-1.mga1
+ Revision: 79182
- Use new plymouth animations

* Thu Mar 31 2011 schultz <schultz> 1.5.0.3-1.mga1
+ Revision: 79136
- update background for beta, update makefile to 1.5.0.3, new tarball 1.5.0.3
+ mikala <mikala>
- Remove BuildRoot
- Add some comments about generating the source file

* Wed Mar 30 2011 mikala <mikala> 1.5.0.2-1.mga1
+ Revision: 79053
- Update tarball to 1.5.0.2:
 Provides mageia screensaver pictures instead of mandriva's one.

* Wed Feb 16 2011 ahmad <ahmad> 1.5.0.1-6.mga1
+ Revision: 52764
- add more obsoletes

* Tue Feb 15 2011 dmorgan <dmorgan> 1.5.0.1-5.mga1
+ Revision: 51792
- Make sure bootsplash is installed before uninstalling

* Tue Feb 15 2011 dmorgan <dmorgan> 1.5.0.1-4.mga1
+ Revision: 51791
- Make sure bootsplash is install thus makes %%post works

* Tue Feb 15 2011 dmorgan <dmorgan> 1.5.0.1-3.mga1
+ Revision: 51790
- Make sure bootsplash is install thus makes %%post works

* Mon Feb 14 2011 misc <misc> 1.5.0.1-2.mga1
+ Revision: 51635
- fix default theme by using the proper file for linking

* Mon Feb 14 2011 dmorgan <dmorgan> 1.5.0.1-1.mga1
+ Revision: 51630
- Fix build
+ misc <misc>
- new version, fix plymouth problem

* Sun Feb 13 2011 tmb <tmb> 1.5.0-1.mga1
+ Revision: 51506
- 1.5.0
  - rename plymouth script to Mageia-Default to match theme name
  - change all paths from mdk to mga

* Sun Feb 13 2011 ennael <ennael> 1.4.9-1.mga1
+ Revision: 51181
- wrong naming Default

* Mon Feb 07 2011 dmorgan <dmorgan> 1.4.8-1.mga1
+ Revision: 48851
- Adapt for mageia
- Fix package name
- Fix obsoletes
- imported package mageia-theme


* Tue Jan 18 2011 Eugeni Dodonov <eugeni@mandriva.com> 1.4.8-1mdv2011.0
+ Revision: 631552
- 1.4.8.
 - Added high-resolution wallpapers from Mandriva 2010.2 contest.

* Wed Jun 23 2010 Frederic Crozat <fcrozat@mandriva.com> 1.4.7-2mdv2010.1
+ Revision: 548706
- Update one of the extra contributor background with full resolution image

* Fri Jun 11 2010 Frederic Crozat <fcrozat@mandriva.com> 1.4.7-1mdv2010.1
+ Revision: 547910
- Update extra backgrounds with better resolution images from authors

* Wed May 26 2010 Frederic Crozat <fcrozat@mandriva.com> 1.4.6-1mdv2010.1
+ Revision: 546295
- Release 1.4.6 :
 - selected community backgrounds for 2010 Spring

* Thu Apr 22 2010 Frederic Crozat <fcrozat@mandriva.com> 1.4.5-1mdv2010.1
+ Revision: 537859
- Release 1.4.5 :
 - fix compatibility with plymouth 0.8.x

* Wed Mar 17 2010 Oden Eriksson <oeriksson@mandriva.com> 1.4.4-2mdv2010.1
+ Revision: 523269
- rebuilt for 2010.1

* Thu Oct 29 2009 Frederic Crozat <fcrozat@mandriva.com> 1.4.4-1mdv2010.0
+ Revision: 460187
- Release 1.4.4 :
 - new screensavers
 - extra subpackage with winning pictures from Mandriva 2010 photo background contest

* Wed Oct 28 2009 Frederic Crozat <fcrozat@mandriva.com> 1.4.3-1mdv2010.0
+ Revision: 459739
- Release 1.4.3 :
 - new design for plymouth themes

* Fri Oct 23 2009 Frederic Crozat <fcrozat@mandriva.com> 1.4.2-1mdv2010.0
+ Revision: 459035
- Release 1.4.2 :
 - new backgrounds for 2010.0

* Wed Oct 14 2009 Frederic Crozat <fcrozat@mandriva.com> 1.4.1-1mdv2010.0
+ Revision: 457323
- Release 1.4.1 :
 - instanciate dialog at startup, when initrd is still running, in case /usr isn't mounted when requested to display them (Mdv bug #54048)

* Thu Oct 08 2009 Frederic Crozat <fcrozat@mandriva.com> 1.4.0-3mdv2010.0
+ Revision: 456031
- Ensure plymouth theme is set during install
- Obsolete plymouth-theme-mdv

* Wed Oct 07 2009 Olivier Blin <oblin@mandriva.com> 1.4.0-2mdv2010.0
+ Revision: 455778
- provide plymouth(system-theme) and require plymouth-system-theme
  instead of providing it (it will pull plymouth as dep)

* Wed Oct 07 2009 Frederic Crozat <fcrozat@mandriva.com> 1.4.0-1mdv2010.0
+ Revision: 455684
- Ship plymouth theme to replace splashy ones

* Mon Sep 28 2009 Frederic Crozat <fcrozat@mandriva.com> 1.3.12-3mdv2010.0
+ Revision: 450615
- Remove dependency on splashy

* Tue Aug 18 2009 Frederic Crozat <fcrozat@mandriva.com> 1.3.12-2mdv2010.0
+ Revision: 417843
- Requires plymouth-system-theme for now

* Thu Apr 23 2009 Frederic Crozat <fcrozat@mandriva.com> 1.3.12-1mdv2009.1
+ Revision: 368830
- Release 1.3.12 :
 - new screensavers

* Fri Apr 10 2009 Frederic Crozat <fcrozat@mandriva.com> 1.3.11-1mdv2009.1
+ Revision: 365884
- Release 1.3.11 :
 fix misalignment in some backgrounds

* Tue Mar 31 2009 Frederic Crozat <fcrozat@mandriva.com> 1.3.10-1mdv2009.1
+ Revision: 363013
- Release 1.3.10 :
 - new graphics for One and Powerpack

* Tue Mar 24 2009 Frederic Crozat <fcrozat@mandriva.com> 1.3.9-1mdv2009.1
+ Revision: 360877
- Release 1.3.9 :
 - updated backgrounds for Free theme
 - improved splashy theme for Free
 - prepare new splashy theme coming for One

* Mon Mar 09 2009 Frederic Crozat <fcrozat@mandriva.com> 1.3.8-1mdv2009.1
+ Revision: 353278
- Release 1.3.8
 - add compat symlink for 1024x600 resolution (Mdv bug #48554)

* Wed Mar 04 2009 Frederic Crozat <fcrozat@mandriva.com> 1.3.7-1mdv2009.1
+ Revision: 348439
- Release 1.3.7 :
 - new theme for 2009 Spring (Free only ATM)
 - update Mandriva-Free.xml to use multiple size

* Wed Sep 10 2008 Frederic Crozat <fcrozat@mandriva.com> 1.3.6-1mdv2009.0
+ Revision: 283501
- Release 1.3.6
 - workaround symlink over hardlink bug

* Tue Sep 09 2008 Frederic Crozat <fcrozat@mandriva.com> 1.3.5-1mdv2009.0
+ Revision: 283161
- Add 640x480 symlink bootsplash (Mdv bug #43715)

* Thu Sep 04 2008 Frederic Crozat <fcrozat@mandriva.com> 1.3.4-1mdv2009.0
+ Revision: 280472
- Improved gfxboot for One / Powerpack (fix logo location)
- Release 1.3.3 :
 - One backgrounds were correctly added to svn this time
- Add compat symlinks for background resolutions not provided (use same ratio image)
- Improve splashy theme a little
- Improve gfxboot theme in One / Powerpack

* Tue Aug 26 2008 Frederic Crozat <fcrozat@mandriva.com> 1.3.1-1mdv2009.0
+ Revision: 276196
- Release 1.3.1 :
 - new design for Mandriva Linux 2009.0

* Fri Aug 08 2008 Thierry Vignaud <tv@mandriva.org> 1.3.0-3mdv2009.0
+ Revision: 267941
- rebuild early 2009.0 package (before pixel changes)

  + Olivier Blin <oblin@mandriva.com>
    - remove useless require for non-existent package
    - require splashy for post/preun scripts
    - 1.3.0
    - build splashy themes

* Tue Jun 10 2008 Olivier Blin <oblin@mandriva.com> 1.2.27.2-1mdv2009.0
+ Revision: 217510
- 1.2.27.2
- add background for Flash 800x480
- add bootsplash for Flash 640x480
- build fixes

* Tue May 13 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.27.1-1mdv2009.0
+ Revision: 206581
- Add theme for new Flash

* Tue Mar 25 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.27-1mdv2008.1
+ Revision: 189925
- Release 1.2.27 : fix Mandriva Free 1440x900 backgrounds (Mdv bug #39163)
- Release 1.2.26 :
 - add another screensaver image, courtesy of Boiko

* Tue Mar 11 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.25-1mdv2008.1
+ Revision: 185270
- Release 1.2.25 : use 12 pixel height for progress bar in bootsplash

* Tue Mar 04 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.24-1mdv2008.1
+ Revision: 178276
- Fix typo in .xml files, breaking background transitions in the morning

* Thu Feb 28 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.23-1mdv2008.1
+ Revision: 176392
- Switch backgrounds to jpeg

* Thu Feb 28 2008 Frederic Crozat <fcrozat@mandriva.com> 1.2.22-1mdv2008.1
+ Revision: 176011
- Fix buildrequires
- Release 1.2.22 :
 - new artwork for Mandriva 2008 Spring, featuring hour based backgrounds

* Wed Feb 27 2008 Olivier Blin <oblin@mandriva.com> 1.2.21-1mdv2008.1
+ Revision: 175696
- 1.2.21
- workaround build for latest gimp (fcrozat)
- restore BuildRoot

  + Thierry Vignaud <tv@mandriva.org>
    - rebuild
    - kill re-definition of %%buildroot on Pixel's request

* Thu Oct 04 2007 Frederic Crozat <fcrozat@mandriva.com> 1.2.20-2mdv2008.0
+ Revision: 95396
- Replace Requires with Suggests on mandriva-theme-screensaver

* Fri Sep 21 2007 Pixel <pixel@mandriva.com> 1.2.20-1mdv2008.0
+ Revision: 91945
- 1.2.20: change pwp and One gfxboot images
  (have Mandriva logo at the same place as Free gfxboot image)

* Wed Sep 19 2007 Olivier Blin <oblin@mandriva.com> 1.2.19-1mdv2008.0
+ Revision: 91218
- 1.2.19: new screensavers

* Tue Sep 11 2007 Olivier Blin <oblin@mandriva.com> 1.2.18-1mdv2008.0
+ Revision: 84379
- 1.2.18: update 1920x1440 images (#33355)

* Fri Sep 07 2007 Olivier Blin <oblin@mandriva.com> 1.2.17-1mdv2008.0
+ Revision: 81946
- 1.2.17 (adapt scripts to build with gimp 2.4 rc2...)
- make Powerpack theme obsolete Powerpack+ theme
- make One theme obsolete Discovery theme
- fix theme name in main description
- remove garbage at end of main description
- 1.2.16
- drop Discovery and Powerpack+ themes
- remove unpackaged files

* Tue Aug 28 2007 Olivier Blin <oblin@mandriva.com> 1.2.15-1mdv2008.0
+ Revision: 72691
- 1.2.15: fix conversion of indexed images (such as gfxboot)

* Mon Aug 27 2007 Olivier Blin <oblin@mandriva.com> 1.2.14-2mdv2008.0
+ Revision: 71994
- 1.2.14 (update theme for Mandriva 2008.0)

* Mon Aug 20 2007 Thierry Vignaud <tv@mandriva.org> 1.2.13-2mdv2008.0
+ Revision: 67872
- add missing requires on perl-base
- convert prereq

* Fri Jun 29 2007 Olivier Blin <oblin@mandriva.com> 1.2.13-1mdv2008.0
+ Revision: 45751
- use Graphics as group
- 1.2.13 (rename Mandriva theme as Mandriva-Free)
- simplify spec now that themes have a common prefix
- make mandriva-theme-Free obsolete mandriva-theme
- make mandriva-theme-Free-screensaver obsolete mandriva-theme-screensaver
- fix inclusion of Powerpack files in Powerpack+ package

* Thu May 10 2007 Olivier Blin <oblin@mandriva.com> 1.2.12-1mdv2008.0
+ Revision: 26082
- 1.2.12 (use final 2007 Spring images for Mandriva-1440x900 and Mandriva-Powerpack+-1280x800)


* Mon Mar 19 2007 Olivier Blin <oblin@mandriva.com> 1.2.11-1mdv2007.1
+ Revision: 146719
- 1.2.11 (do not make progress bar overlap text, #29373)

* Wed Mar 14 2007 Pixel <pixel@mandriva.com> 1.2.10-1mdv2007.1
+ Revision: 143599
- compress even less gfxboot images

* Tue Mar 13 2007 Pixel <pixel@mandriva.com> 1.2.9-1mdv2007.1
+ Revision: 142425
- new release, 1.2.9:
- add gfxboot images

* Mon Mar 12 2007 Olivier Blin <oblin@mandriva.com> 1.2.8-1mdv2007.1
+ Revision: 141638
- 1.2.8 (new vt images)

* Tue Mar 06 2007 Olivier Blin <oblin@mandriva.com> 1.2.7-1mdv2007.1
+ Revision: 134057
- 1.2.7 (add hibernate images back)

* Mon Mar 05 2007 Olivier Blin <oblin@mandriva.com> 1.2.6-1mdv2007.1
+ Revision: 133393
- 1.2.6 (new screensavers)

* Mon Mar 05 2007 Olivier Blin <oblin@mandriva.com> 1.2.5-1mdv2007.1
+ Revision: 132855
- 1.2.5 (convert hibernate images as jpg)
- 1.2.4
- remove old symlinks to old kde config files in trigger
- install common images (vt and hibernate) in /usr/share/bootsplash/Mandriva-common/images
- move vt backgrounds in common subpackage
- remove unused kdeglobals/konsolerc/kwinrc files (replaced by *-kde-config profiles)
- cosmetics
- factorize again
- use shell pattern to get background prefix instead of hardcoded values
- factorize post/preun

* Mon Feb 26 2007 Olivier Blin <oblin@mandriva.com> 1.2.3-2mdv2007.1
+ Revision: 126098
- bump release

  + Frederic Crozat <fcrozat@mandriva.com>
    - Don't include all backgrounds in free package

* Thu Feb 15 2007 Warly <warly@mandriva.com> 1.2.3-1mdv2007.1
+ Revision: 121414
- update tarball and spec for version 1.2.3

* Wed Feb 14 2007 Warly <warly@mandriva.com> 1.2.2-1mdv2007.1
+ Revision: 120981
- update tarball and spec for version 1.2.2

* Tue Feb 13 2007 Warly <warly@mandriva.com> 1.2.1-1mdv2007.1
+ Revision: 120472
- update tarball and spec for version 1.2.1

* Tue Feb 13 2007 Warly <warly@mandriva.com> 1.2.0-1mdv2007.1
+ Revision: 120446
- update tarball and spec for version 1.2.0
- Import mandriva-theme

* Wed Sep 20 2006 Warly <warly@mandriva.com> 1.1.4-1mdv2007.0
- fix lilo message generation

* Tue Sep 19 2006 Warly <warly@mandriva.com> 1.1.3-1mdv2007.0
- try to improve bootsplash jpeg image, store png image as source
  and regenerate during the build the jpeg with good quality

* Thu Sep 14 2006 Warly <warly@mandriva.com> 1.1.2-1mdv2007.0
- adjust progress bar color

* Wed Sep 13 2006 Warly <warly@mandriva.com> 1.1.1-1mdv2007.0
- some adjustment in the lilo images

* Thu Jul 13 2006 Warly <warly@mandriva.com> 1.1.0-1mdv2007.0
- test version for 2007

* Sat Sep 24 2005 Frederic Lepied <flepied@mandriva.com> 1.0.12-1mdk
- rebuild to have the common part in kdeglobals

* Wed Sep 14 2005 Warly <warly@mandriva.com> 1.0.11-1mdk
- fixed tux images for screensaver

* Wed Sep 14 2005 Pixel <pixel@mandriva.com> 1.0.10-2mdk
- we need special bootsplash to be installed to correctly upgrade from mandrakelinux-theme
  (cf bootsplash 3.1.8-3mdk changelog)

* Tue Sep 13 2005 Warly <warly@mandriva.com> 1.0.10-1mdk
- improve bootsplash image quality
- move text window
- change progress bar color

* Sat Sep 10 2005 Frederic Lepied <flepied@mandriva.com> 1.0.9-1mdk
- move konsolerc to this package

* Fri Sep 09 2005 Warly <warly@mandriva.com> 1.0.8-4mdk
- remove mandriva-theme non versionned provides

* Thu Sep 08 2005 Warly <warly@mandriva.com> 1.0.8-3mdk
- fix kdeglobals name

* Wed Sep 07 2005 Laurent MONTEL <lmontel@mandriva.com> 1.0.8-2mdk
- Move kdeglobals here

* Tue Sep 06 2005 Warly <warly@mandriva.com> 1.0.8-1mdk
- update screensaver image

* Sat Sep 03 2005 Warly <warly@mandriva.com> 1.0.7-1mdk
- fix bootloader progress bar

* Tue Aug 30 2005 Warly <warly@mandriva.com> 1.0.5-1mdk
- various theme corrections
- split screensaver

* Tue Aug 23 2005 Warly <warly@mandriva.com> 1.0.4-1mdk
- new themes

* Wed Aug 03 2005 Warly <warly@mandriva.com> 1.0.3-1mdk
- new background

* Thu Jul 28 2005 Warly <warly@mandriva.com> 1.0.2-1mdk
- include screen saver

* Wed Jul 13 2005 Warly <warly@mandriva.com> 1.0.1-1mdk
- fix configuration file which still refered to Mandrakelinux pathes

* Thu Jun 30 2005 Warly <warly@mandriva.com> 1.0.0-1mdk
- Mandrakelinux->Mandriva
- New theme

* Tue Apr 05 2005 Warly <warly@mandrakesoft.com> 0.3.6-1mdk
- The configuration file for 1280x1024 was wrong.
- Move down the text in resolution other than 800x600

* Tue Apr 05 2005 Warly <warly@mandrakesoft.com> 0.3.5-1mdk
- Really change the background

* Tue Apr 05 2005 Warly <warly@mandrakesoft.com> 0.3.4-1mdk
- Now default background is stars only

* Sat Apr 02 2005 Warly <warly@mandrakesoft.com> 0.3.3-1mdk
- fix the eyes

* Wed Mar 23 2005 Warly <warly@mandrakesoft.com> 0.3.2-1mdk
- fix lilo progress bar size

* Tue Mar 22 2005 Warly <warly@mandrakesoft.com> 0.3.1-1mdk
- include new definitions images
- try to update progress bar position in higher definitions than 800x600

* Mon Mar 21 2005 Warly <warly@mandrakesoft.com> 0.3.0-1mdk
- Limited Edition 2005 theme

* Thu Mar 10 2005 Warly <warly@mandrakesoft.com> 0.2.20-1mdk
- updated for rc1

* Tue Feb 22 2005 Warly <warly@mandrakesoft.com> 0.2.19-1mdk
- fix bad jpeg format

* Mon Feb 21 2005 Warly <warly@mandrakesoft.com> 0.2.18-1mdk
- theme for 10.2 beta 3
- add new x,y position for animation
- try to stop animation sooner, not to have it remaining in console mode

* Fri Feb 04 2005 Warly <warly@mandrakesoft.com> 0.2.17-1mdk
- theme for 10.2 beta 2

* Fri Jan 21 2005 Warly <warly@mandrakesoft.com> 0.2.16-1mdk
- 10.2 beta

* Fri Dec 24 2004 Warly <warly@mandrakesoft.com> 0.2.15-1mdk
- Cooker Xmas theme

* Tue Aug 24 2004 Warly <warly@mandrakesoft.com> 0.2.10-2mdk
- obsolete also mandrake-theme

* Wed Aug 04 2004 Warly <warly@mandrakesoft.com> 0.2.10-1mdk
- fix theme name in config file

* Fri Jul 30 2004 Warly <warly@mandrakesoft.com> 0.2.9-1mdk
- fix corporate configuration files

* Fri Jul 30 2004 Warly <warly@mandrakesoft.com> 0.2.8-1mdk
- fix post install scripts
- add prereq on bootplash for extra packages (server and desktop)

* Thu Jul 29 2004 Warly <warly@mandrakesoft.com> 0.2.7-1mdk
- include corporate server and desktop theme
- more Mandrake->Mandrakelinux switches

* Thu Jul 29 2004 Warly <warly@mandrakesoft.com> 0.2.5-4mdk
- coporate server 3.0

* Wed Jul 14 2004 Warly <warly@mandrakesoft.com> 0.2.5-3mdk
- Euskara version

* Wed May 12 2004 Warly <warly@mandrakesoft.com> 0.2.5-2mdk
- 10.0 Shuttle version

